<?php

namespace Asadi\Mark\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Asadi\Mark\Interfaces\MarkRepositoryInterface;
use Asadi\Mark\Repositories\Presenter\MarkItemTransformer;

/**
 * Pubic API controller class.
 */
class MarkPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Asadi\Mark\Interfaces\MarkRepositoryInterface $mark
     *
     * @return type
     */
    public function __construct(MarkRepositoryInterface $mark)
    {
        $this->repository = $mark;
        parent::__construct();
    }

    /**
     * Show mark's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $marks = $this->repository
            ->setPresenter('\\Asadi\\Mark\\Repositories\\Presenter\\MarkListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $marks['code'] = 2000;
        return response()->json($marks)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show mark.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $mark = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($mark)) {
            $mark         = $this->itemPresenter($module, new MarkItemTransformer);
            $mark['code'] = 2001;
            return response()->json($mark)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
