<?php

namespace Asadi\Mark\Http\Controllers;
use Litepie\Mark\Http\Requests\MarkRequest;
use Litepie\Mark\Models\Mark;

trait MarkWorkflow {
	
    /**
     * Workflow controller function for mark.
     *
     * @param Model   $mark
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(MarkRequest $request, Mark $mark, $step)
    {

        try {

            $mark->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('mark::mark.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/mark/mark/' . $mark->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/mark/mark/' . $mark->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for mark.
     *
     * @param Model   $mark
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Mark $mark, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $mark->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('mark::mark.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('mark::admin.mark.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('mark::admin.mark.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('mark::admin.mark.message', $data)->render();

        }

    }
}