<?php

namespace Asadi\Mark\Policies;

use App\User;
use Asadi\Mark\Models\Mark;

class MarkPolicy
{

    /**
     * Determine if the given user can view the mark.
     *
     * @param User $user
     * @param Mark $mark
     *
     * @return bool
     */
    public function view(User $user, Mark $mark)
    {
        if ($user->canDo('mark.mark.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $mark->user_id;
    }

    /**
     * Determine if the given user can create a mark.
     *
     * @param User $user
     * @param Mark $mark
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('mark.mark.create');
    }

    /**
     * Determine if the given user can update the given mark.
     *
     * @param User $user
     * @param Mark $mark
     *
     * @return bool
     */
    public function update(User $user, Mark $mark)
    {
        if ($user->canDo('mark.mark.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $mark->user_id;
    }

    /**
     * Determine if the given user can delete the given mark.
     *
     * @param User $user
     * @param Mark $mark
     *
     * @return bool
     */
    public function destroy(User $user, Mark $mark)
    {
        if ($user->canDo('mark.mark.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $mark->user_id;
    }

    /**
     * Determine if the given user can verify the given mark.
     *
     * @param User $user
     * @param Mark $mark
     *
     * @return bool
     */
    public function verify(User $user, Mark $mark)
    {
        if ($user->canDo('mark.mark.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('mark.mark.verify') 
        && $user->is('manager')
        && $mark->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given mark.
     *
     * @param User $user
     * @param Mark $mark
     *
     * @return bool
     */
    public function approve(User $user, Mark $mark)
    {
        if ($user->canDo('mark.mark.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
