<?php

namespace Asadi\Mark\Providers;

use Illuminate\Support\ServiceProvider;

class MarkServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'mark');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'mark');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('mark', function ($app) {
            return $this->app->make('Asadi\Mark\Mark');
        });

        // Bind Mark to repository
        $this->app->bind(
            \Asadi\Mark\Interfaces\MarkRepositoryInterface::class,
            \Asadi\Mark\Repositories\Eloquent\MarkRepository::class
        );

        $this->app->register(\Asadi\Mark\Providers\AuthServiceProvider::class);
        $this->app->register(\Asadi\Mark\Providers\EventServiceProvider::class);
        $this->app->register(\Asadi\Mark\Providers\RouteServiceProvider::class);
        // $this->app->register(\Asadi\Mark\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['mark'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('asadi/mark.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/mark')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/mark')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
