<?php

namespace Asadi\Mark\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Asadi\Mark\Models\Mark;

class MarkAction
{
    /**
     * Perform the complete action.
     *
     * @param Mark $mark
     *
     * @return Mark
     */
    public function complete(Mark $mark)
    {
        try {
            $mark->status = 'complete';
            return $mark->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Mark $mark
     *
     * @return Mark
     */public function verify(Mark $mark)
    {
        try {
            $mark->status = 'verify';
            return $mark->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Mark $mark
     *
     * @return Mark
     */public function approve(Mark $mark)
    {
        try {
            $mark->status = 'approve';
            return $mark->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Mark $mark
     *
     * @return Mark
     */public function publish(Mark $mark)
    {
        try {
            $mark->status = 'publish';
            return $mark->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Mark $mark
     *
     * @return Mark
     */
    public function archive(Mark $mark)
    {
        try {
            $mark->status = 'archive';
            return $mark->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Mark $mark
     *
     * @return Mark
     */
    public function unpublish(Mark $mark)
    {
        try {
            $mark->status = 'unpublish';
            return $mark->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
