<?php

namespace Asadi\Mark\Workflow;

use Asadi\Mark\Models\Mark;
use Validator;

class MarkValidator
{

    /**
     * Determine if the given mark is valid for complete status.
     *
     * @param Mark $mark
     *
     * @return bool / Validator
     */
    public function complete(Mark $mark)
    {
        return Validator::make($mark->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given mark is valid for verify status.
     *
     * @param Mark $mark
     *
     * @return bool / Validator
     */
    public function verify(Mark $mark)
    {
        return Validator::make($mark->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given mark is valid for approve status.
     *
     * @param Mark $mark
     *
     * @return bool / Validator
     */
    public function approve(Mark $mark)
    {
        return Validator::make($mark->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given mark is valid for publish status.
     *
     * @param Mark $mark
     *
     * @return bool / Validator
     */
    public function publish(Mark $mark)
    {
        return Validator::make($mark->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given mark is valid for archive status.
     *
     * @param Mark $mark
     *
     * @return bool / Validator
     */
    public function archive(Mark $mark)
    {
        return Validator::make($mark->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given mark is valid for unpublish status.
     *
     * @param Mark $mark
     *
     * @return bool / Validator
     */
    public function unpublish(Mark $mark)
    {
        return Validator::make($mark->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
